@@ -108,14 +108,12 @@ class ClefEngraver(Engraver):
               'mezzosoprano': 'C',
               'soprano': 'C',
               'french': 'G'}[self.m_cleftype]
-        im = gtk.Image()
-        im.set_from_file(fetadir+'/feta%i-clefs-%s.xpm' % (self.m_fontsize, fn))
-        im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                    self.m_xpos,
-                    dimentions[self.m_fontsize].clef_yoffset[self.m_cleftype] \
-                     + staff_yoffset, -1, -1,
-                     gtk.gdk.RGB_DITHER_NONE, 0, 0)
-
+        widget.window.draw_pixbuf(gc,
+            gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-clefs-%s.xpm' \
+                % (self.m_fontsize, fn)),
+            0, 0, self.m_xpos,
+            dimentions[self.m_fontsize].clef_yoffset[self.m_cleftype] \
+                + staff_yoffset)
 
 class TimeSignatureEngraver(Engraver):
     def __init__(self, timepos, fontsize, timesig):
@@ -127,20 +125,20 @@ class TimeSignatureEngraver(Engraver):
         x = 0
         for idx in range(len(str(self.m_timesig.m_num))):
             n = str(self.m_timesig.m_num)[idx]
-            im = gtk.Image()
-            im.set_from_file(fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))
-            im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                    self.m_xpos+x, staff_yoffset-12, -1, -1,
-                    gtk.gdk.RGB_DITHER_NONE, 0, 0)
+            widget.window.draw_pixbuf(gc,
+                gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-number-%s.xpm' \
+                    % (self.m_fontsize, n)),
+                0, 0,
+                self.m_xpos+x, staff_yoffset-12)
             x  += 10
         x = 0
         for idx in range(len(str(self.m_timesig.m_den))):
             n = str(self.m_timesig.m_den)[idx]
-            im = gtk.Image()
-            im.set_from_file(fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))
-            im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                    self.m_xpos+x, staff_yoffset+3, -1, -1,
-                    gtk.gdk.RGB_DITHER_NONE, 0, 0)
+            widget.window.draw_pixbuf(gc,
+                gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-number-%s.xpm' %\
+                    (self.m_fontsize, n)),
+                0, 0,
+                self.m_xpos+x, staff_yoffset+3)
             x += 10
     def __str__(self):
         return '(TimeSignatureEngraver:%i/%i, xpos:%s)' % (self.m_timesig.m_den,
@@ -187,15 +185,15 @@ class AccidentalsEngraver(Engraver):
         x = 0
         for y in self.m_accs:
             for acc in self.m_accs[y]:
-                im = gtk.Image()
-                im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, acc))
-                im.get_pixbuf().render_to_drawable(widget.window, gc,
+                widget.window.draw_pixbuf(gc,
+                    gtk.gdk.pixbuf_new_from_file(
+                        fetadir+'/feta%i-accidentals-%i.xpm' % \
+                            (self.m_fontsize, acc)),
                         0, 0,
                         self.m_xpos + x,
                         int(accidental_y_offset[acc] + staff_yoffset
                          + dimentions[self.m_fontsize].linespacing*y/2
-                         + accidental_y_offset[acc]),
-                        -1, -1, gtk.gdk.RGB_DITHER_NONE, 0, 0)
+                         + accidental_y_offset[acc]))
                 x += dimentions[self.m_fontsize].accidental_widths[acc] + 1
 
 
@@ -240,14 +238,15 @@ class KeySignatureEngraver(Engraver):
             #FIXME see FIXME msg in .get_width
             x += 10
         for type, x, ypos in dolist:
-            im = gtk.Image()
-            im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, type))
-            im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                    self.m_xpos + x,
-                    int(accidental_y_offset[type] + staff_yoffset
+            widget.window.draw_pixbuf(gc,
+                gtk.gdk.pixbuf_new_from_file(
+                    fetadir+'/feta%i-accidentals-%i.xpm' \
+                    % (self.m_fontsize, type)),
+                0, 0,
+                self.m_xpos + x,
+                int(accidental_y_offset[type] + staff_yoffset
                      + dimentions[self.m_fontsize].linespacing*ypos/2
-                     + accidental_y_offset[type]), -1, -1,
-                     gtk.gdk.RGB_DITHER_NONE, 0, 0)
+                     + accidental_y_offset[type]))
 
 
 class NoteheadEngraver(Engraver):
@@ -270,20 +269,18 @@ class NoteheadEngraver(Engraver):
         self.m_xpos = dict[self.m_timepos].m_music
     def engrave(self, widget, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        im = gtk.Image()
-        im.set_from_file(fetadir+'/feta%i-noteheads-%i.xpm' % (self.m_fontsize, self.m_head))
-        im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                    self.m_xpos + self.m_shift * dim.xshift,
-                    int(staff_yoffset + dim.linespacing*self.m_ypos/2 - 4),
-                    -1, -1,
-                     gtk.gdk.RGB_DITHER_NONE, 0, 0)
-        im.set_from_file(fetadir+'/feta20-dots-dot.xpm')
+        widget.window.draw_pixbuf(gc, 
+            gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-noteheads-%i.xpm' \
+                % (self.m_fontsize, self.m_head)),
+            0, 0,
+            self.m_xpos + self.m_shift * dim.xshift,
+            int(staff_yoffset + dim.linespacing*self.m_ypos/2 - 4))
         for n in range(self.m_numdots):
-            im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
-                        int(self.m_xpos+dim.xshift*(self.m_shift+1.5+n/2.0)),
-                        -3 + staff_yoffset + dim.linespacing*self.m_ypos/2,
-                        -1, -1,
-                     gtk.gdk.RGB_DITHER_NONE, 0, 0)
+            widget.window.draw_pixbuf(gc,
+                gtk.gdk.pixbuf_new_from_file(fetadir+'/feta20-dots-dot.xpm'),
+                0, 0,
+                int(self.m_xpos+dim.xshift*(self.m_shift+1.5+n/2.0)),
+                -3 + staff_yoffset + dim.linespacing*self.m_ypos/2)
     def get_pixmap_id(self):
         return {0: const.NOTEHEAD_0,
                 1: const.NOTEHEAD_1,
@@ -405,9 +402,9 @@ class BeamEngraver(Engraver):
         dim = dimentions[self.m_fontsize]
         d = 0
         if self.m_stemdir == const.UP:
-           d = 1
+            d = 1
         else:
-           d = -1
+            d = -1
         x1 = self.m_stems[0].m_xpos
         x2 = self.m_stems[-1].m_xpos
         if self.m_stems[0].m_beamed_stem_top % 2 == 1:
@@ -449,8 +446,8 @@ class BeamEngraver(Engraver):
                     short_beam(self.m_stems[i], dir, yc+1, d)
                     self.m_stems[i]._beam_done = nl
             if self.m_stems[-1].m_mgroup.m_duration.m_nh >= nl \
-                 and self.m_stems[-1]._beam_done <= nl/2:
-                 short_beam(self.m_stems[-1], -1, yc+1, d)
+                    and self.m_stems[-1]._beam_done <= nl/2:
+                short_beam(self.m_stems[-1], -1, yc+1, d)
 
 
 class StemEngraver(Engraver):
@@ -482,19 +479,21 @@ class StemEngraver(Engraver):
         # draw flags
         if not self.m_is_beamed and self.m_mgroup.m_duration.m_nh > 4:
             if self.m_mgroup.m_stemdir == const.UP:
-                im = gtk.Image()
-                im.set_from_file(fetadir+'/feta%i-flags-%s.xpm' % (self.m_fontsize, self.get_flag(const.UP)))
-                im.get_pixbuf().render_to_drawable(widget.window, widget.get_style().black_gc, 0, 0,
-                            self.m_xpos,
-                            int(staff_yoffset - self.m_stemlen + self.m_yposes[0] * dim.linespacing/2),
-                            -1, -1, gtk.gdk.RGB_DITHER_NONE, 0, 0)
+                widget.window.draw_pixbuf(gc,
+                    gtk.gdk.pixbuf_new_from_file(
+                        fetadir+'/feta%i-flags-%s.xpm' % \
+                            (self.m_fontsize, self.get_flag(const.UP))),
+                    0, 0,
+                    self.m_xpos,
+                    int(staff_yoffset - self.m_stemlen + self.m_yposes[0] * dim.linespacing/2))
             else:
-                im = gtk.Image()
-                im.set_from_file(fetadir+'/feta%i-flags-%s.xpm' % (self.m_fontsize, self.get_flag(const.DOWN)))
-                im.get_pixbuf().render_to_drawable(widget.window, widget.get_style().black_gc, 0, 0,
-                            self.m_xpos,
-                            int(staff_yoffset + 4 + self.m_yposes[-1] * dim.linespacing/2),
-                            -1, -1, gtk.gdk.RGB_DITHER_NONE, 0, 0)
+                widget.window.draw_pixbuf(gc,
+                    gtk.gdk.pixbuf_new_from_file(
+                        fetadir+'/feta%i-flags-%s.xpm' \
+                        % (self.m_fontsize, self.get_flag(const.DOWN))),
+                    0, 0,
+                    self.m_xpos,
+                    int(staff_yoffset + 4 + self.m_yposes[-1] * dim.linespacing/2))
         # draw stem
         if self.m_mgroup.m_stemdir == const.DOWN:
             if self.m_is_beamed:
@@ -571,18 +570,16 @@ class RestEngraver(Engraver):
         return 20
     def engrave(self, widget, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        im = gtk.Image()
-        im.set_from_file(fetadir+'/feta%i-rests-%i.xpm' % (self.m_fontsize, self.m_type))
         if self.m_type == 0:
             my = dim.linespacing/2
         else:
             my = 0
-        im.get_pixbuf().render_to_drawable(widget.window, widget.get_style().black_gc,
-                    0, 0,
-                    self.m_xpos,
-                    int(staff_yoffset - my + dim.linespacing*self.m_ypos/2 - 4),
-                    -1, -1,
-                    gtk.gdk.RGB_DITHER_NONE, 0, 0)
+        widget.window.draw_pixbuf(gc,
+            gtk.gdk.pixbuf_new_from_file(fetadir+'/feta%i-rests-%i.xpm' \
+                % (self.m_fontsize, self.m_type)),
+            0, 0,
+            self.m_xpos,
+            int(staff_yoffset - my + dim.linespacing*self.m_ypos/2 - 4))
     def get_pixmap_id(self):
         return {1: const.REST_1,
                 2: const.REST_2,
