@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,6 +19,12 @@
 Only utility functions and classes that are private to the mpd module
 should go into this file.
 """
+if __name__ == "__main__":
+    import sys
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
+
 from musicalpitch import MusicalPitch
 import _exceptions
 
@@ -39,7 +45,6 @@ def int_to_user_notename(i):
     p.set_from_int(i)
     return p.get_user_octave_notename()
 
-
 def notename_to_int(n):
     p = MusicalPitch.new_from_notename(n)
     return p.semitone_pitch()
@@ -61,7 +66,7 @@ def steps_to_ylinepos(steps, clef):
             'mezzosoprano': 9,
             'soprano': 11,
             'french': 15}[clef] - steps
-    except:
+    except KeyError:
         raise UnknownClefException(clef)
 
 def notename_to_ylinepos(n, clef):
