@@ -1,4 +1,4 @@
-#!/usr/bin/python2.2
+#!/usr/bin/python
 # GNU Solfege - ear training for GNOME
 # Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
@@ -50,7 +50,7 @@ exercises = ('chord',
              'sing-chord',
              'rhythm',
              'identify-bpm',
-             'harmonic-progression-dictation'
+             #'harmonic-progression-dictation'
              )
 
 msg1 = _("""Because not all documents has been
@@ -65,7 +65,7 @@ def get_title_of_file(dir, filename, source_encoding):
         dir = 'online-docs/C'
     try:
         s = open(os.path.join(dir, filename)).read()
-        r = re.compile(".*?<title>(.*?)</title>", re.DOTALL)
+        r = re.compile(".*?<h1>(.*?)</h1>", re.DOTALL)
         m = r.match(s)
         ret =m.groups()[0]
         if source_encoding != 'UTF-8':
@@ -74,19 +74,8 @@ def get_title_of_file(dir, filename, source_encoding):
     except IOError:
         return "error: file not found:", filename
 
-def find_encoding(xmlfile):
-    """
-    Return a string with the encoding of a .xml file.
-    """
-    ifile = file(xmlfile, 'r')
-    s = ifile.read()
-    ifile.close()
-    m = re.search('encoding="(.*?)"', s)
-    return m.groups()[0]
-
 def write_html_toc(lang):
-    #source_encoding = find_encoding(os.path.join(lang, "solfege.xml"))
-    source_encoding = "iso-8859-1" #FIXME
+    source_encoding = "UTF-8"
     fn = os.path.join(lang, 'toc.html')
     f = file(fn, 'w')
     if lang == 'online-docs/C':
@@ -154,7 +143,16 @@ BODY {
 <dl>
 """ % _("Extending and translating Solfege").encode("UTF-8"))
     for fn in devel_docs:
-        f.write('\n <dt></dt><dd><a href="%s.html">%s</a></dd>' % (fn, get_title_of_file(lang, fn+'.html', source_encoding)))
+        def un_html(s):
+            while 1:
+                r = re.compile("\<.*?\>")
+                m = r.search(s)
+                if not m:
+                    break
+                s = s[:m.start()]+s[m.end():]
+            return s
+        title = un_html(get_title_of_file(lang, fn+'.html', source_encoding))
+        f.write('\n <dt></dt><dd><a href="%s.html">%s</a></dd>' % (fn, title))
     f.write("""
 </dl>
 </body></html>
