@@ -52,7 +52,7 @@ class MidiFileSynth:
             print "Exception:", e
             raise "Shit"
     def close(self):
-        pass
+        os.remove(self.m_tmpfilename)
     def join_cmd_and_filename(self, cmd, filename):
         if "%s" in cmd:
             return cmd % filename
