@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ import os
 import sys
 import signal
 import cfg
+import intervaltest
 
 class Teacher(cfg.ConfigUtils):
     def __init__(self, exname, app, config):
@@ -386,7 +387,10 @@ class IntervalGui(Gui):
         self.g_input.show()
         self.m_notenamerange.set_range(self.g_input.m_lowest_tone,
                                        self.g_input.m_highest_tone)
-        self.on_end_practise()
+        if self.m_t.m_tonika:
+            # Don't call on_end_practise if we are starting up the exercise.
+            # This whole thing is a mess.
+            self.on_end_practise()
         self.g_disable_unused_buttons.set_sensitive(self.get_int('inputwidget')==0)
     def setup_key_bindings(self):
         keys = ['minor2', 'major2', 'minor3', 'major3',
@@ -399,6 +403,22 @@ class IntervalGui(Gui):
     def repeat_question(self, *w):
         self.m_t.play_question()
         self.g_input.grab_focus_first_sensitive_button()
+    def show_test_statistics(self, action):
+        if self.g_test_stat_dlg:
+            self.g_test_stat_dlg.destroy()
+            self.g_test_stat_dlg = None
+        t = intervaltest.Test(self.m_t.m_exname)
+        self.g_test_stat_dlg = intervaltest.TestStatisticsDialog(self, _("Test statistics"), t.get_total_results())
+        self.g_test_stat_dlg.show_all()
+        self.g_test_stat_dlg.connect('delete-event', self.destroy_test_stat_dlg)
+    def destroy_test_stat_dlg(self, *ignore):
+        """
+        The self.g_test_stat_dlg is used both for the dialog showing
+        the test statistics and the test results.
+        """
+        assert self.g_test_stat_dlg
+        self.g_test_stat_dlg.destroy()
+        self.g_test_stat_dlg = None
 
 
 class LessonbasedGui(Gui):
