@@ -46,7 +46,7 @@ class RunExternalFailed(Exception):
 __child_pid = None
 def run_external_program(cmdstring, wdir, argument):
     global __child_pid
-    if cmdstring.find("%s") == -1:
+    if "%s" not in cmdstring:
         cmdline = "%s %s" % (cmdstring, argument)
     else:
         cmdline = cmdstring % argument
@@ -80,9 +80,12 @@ def run_external_program(cmdstring, wdir, argument):
         __child_pid = pid
 
 class SolfegeApp(cfg.ConfigUtils):
-    def __init__(self, argv, ui):
+    def __init__(self, options, ui):
+        """
+        options -- command line options parsed by optparse
+        """
         cfg.ConfigUtils.__init__(self, 'solfege-app')
-        self.m_argv = argv
+        self.m_options = options
         self.m_ui = ui
         self.check_rcfile()
         self.m_teachers = {}
@@ -94,41 +97,52 @@ class SolfegeApp(cfg.ConfigUtils):
         """See default.config for rcfileversion values, meanings and
         a description of how to add config variables.
         """
-        if cfg.get_int("app/rcfileversion") > 5:
+        rcfileversion = 6
+        if cfg.get_int("app/rcfileversion") > rcfileversion:
             cfg.drop_user_config()
             return
         if cfg.get_int("app/rcfileversion") <= 1:
             if not "example-files" in cfg.get_string('config/lessoncollections'):
                 cfg.set_string('config/lessoncollections', 
                     "%s example-files" % cfg.get_string('config/lessoncollections'))
-        if cfg.get_int("app/rcfileversion") <= 2:
-            cfg.del_key("sound/commandline")
+        if cfg.get_int("app/rcfileversion") <= 5:
+            # This is more complicated that necessary to fix an old
+            # error.
+            if cfg.get_string("sound/commandline"):
+                cfg.del_key("sound/commandline")
         if cfg.get_int("app/rcfileversion") <= 3:
             cfg.set_list("config/lessoncollections",
                 cfg.get_string("config/lessoncollections").split())
         if cfg.get_int("app/rcfileversion") <= 4:
             cfg.del_key("config/web_browser")
-        cfg.set_int("app/rcfileversion", 5)
+        if sys.platform == 'win32':
+            if cfg.get_string('sound/wav_player'):
+                cfg.del_key('sound/wav_player')
+        if cfg.get_int("app/rcfileversion") <= 5:
+            cfg.set_string("mainwin/history_back_ak", "<alt>Left")
+            cfg.set_string("mainwin/history_forward_ak", "<alt>Right")
+            cfg.set_string("mainwin/history_reload_ak", "<ctrl>r")
+        cfg.set_int("app/rcfileversion", rcfileversion)
     def setup_sound(self):
         if sys.platform == 'win32' and \
                     cfg.get_string("sound/type") == "sequencer-device":
             # just in case c:\home\.solfegerc is wrong
             cfg.set_string("sound/type", "winsynth")
-        if '--no-sound' in self.m_argv \
+        if self.m_options.no_sound \
            or cfg.get_string("sound/type") == "fake-synth":
-            soundcard.initialise_using_fake_synth('--verbose-sound-init' in self.m_argv)
+            soundcard.initialise_using_fake_synth(self.m_options.verbose_sound_init)
         elif cfg.get_string("sound/type") == "winsynth":
             try:
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
-                      verbose_init='--verbose-sound-init' in self.m_argv)
+                      verbose_init=self.m_options.verbose_sound_init)
             except:#FIXME should use except: ExceptionName
                 cfg.set_int("sound/synth_number", 0)
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
-                      verbose_init='--verbose-sound-init' in self.m_argv)
+                      self.m_options.verbose_sound_init)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
                     cfg.get_string("sound/midi_player"),
-                    verbose_init='--verbose-sound-init' in self.m_argv)
+                    verbose_init=self.m_options.verbose_sound_init)
         elif cfg.get_string("sound/type") == '':
             self.m_ui.display_error_message(
 """You should configure sound
@@ -144,14 +158,20 @@ the preferences window.
                              cfg.get_string("sound/device_file"),
                              cfg.get_int("sound/synth_number"),
                              cfg.get_string("sound/card_info"),
-                             verbose_init='--verbose-sound-init' in self.m_argv)
-            except (soundcard.SoundInitException, OSError), e:
+                             verbose_init=self.m_options.verbose_sound_init)
+            except (soundcard.SoundInitException, OSError, ImportError), e:
                 self.m_sound_init_exception = e
                 soundcard.initialise_using_fake_synth(True)
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
             """%s""" % e)
+        elif isinstance(e, ImportError):
+            self.m_ui.display_error_message("%(message)s\n%(exception)s\n\n%(todo)s" % {
+              'exception':e,
+              'message': "<b>%s</b>" % _("Error loading python module:"),
+              'todo': _("Now you should configure sound from the preferences window."),
+              })
         elif e.errno == errno.EACCES:
             self.m_ui.display_error_message(
 """The sound init failed: %s
@@ -193,56 +213,67 @@ It is also possible that the OS sound setup is incorrect.
            utils.parse_url(href)
         if protocol is None:
             if fn.endswith(".midi"):
+                if os.path.exists(os.path.join(self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd,fn)):
+                    midifilename = fn
+                elif len(fn.split('-')) > 1:
+                    # Filename-nl.midi => Filename.midi
+                    v = fn.split('-')
+                    w = v[-1].split('.')
+                    midifilename = "-".join(v[:-1])+"."+w[1]
+                else:
+                    midifilename = fn
                 run_external_program(self.get_string("sound/midi_player"),
-                        self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, fn)
+                        self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, midifilename)
             else:
                 self.m_ui.display_docfile(fn, anchor)
         elif protocol == 'solfege':
-            if action == 'all-lessonfiles':
-                self.m_ui.display_html(self.lessonfile_manager.m_htmldoc)
-                self.m_ui.m_history.add('solfege:all-lessonfiles')
-            else:
-                if lessonfile:
-                    filepath = os.path.join(self.get_string('lessoncollections/%s' %lessoncollection), lessonfile)
-                    if not os.path.isfile(filepath):
-                        self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
-                        return
-                if (self.m_ui.m_viewer == 'docviewer'
-                           and self.m_running_exercise is not None
-                           and self.m_running_exercise != fn) or \
-                          (self.m_ui.m_viewer != 'docviewer'):
-                    self.m_ui.box_dict[self.m_running_exercise].on_end_practise()
-                    self.m_running_exercise = None
-                _old_viewer = self.m_ui.m_viewer
-                if fn not in self.m_teachers:
-                    new_ex = True
-                    n = utils.exercise_name_to_module_name(fn)
-                    exec("import %s" % n)
-                    if issubclass(locals()[n].Teacher, abstract.LessonbasedTeacher):
-                        self.m_teachers[fn] = locals()[n].Teacher(fn, self, lessoncollection, lessonfile, config)
-                    else:
-                        self.m_teachers[fn] = locals()[n].Teacher(fn, self, config)
-                    # if we don't have a teacher, then the Gui has not been
-                    # initialized either
-                    self.m_ui.initialise_exercise(self.m_teachers[fn])
-                    self.m_teachers[fn].g_view = self.m_ui.box_dict[fn]
-                else:
-                    new_ex = False
-                    self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
-                self.m_ui.activate_exercise(href)
-                if not new_ex and 'update_gui_after_lessonfile_change' in dir(self.m_ui.box_dict[fn]):
-                    self.m_ui.box_dict[fn].update_gui_after_lessonfile_change()
-                if not (_old_viewer == 'docviewer'
-                        and self.m_running_exercise is not None
-                        and self.m_running_exercise == fn):
-                    self.m_ui.box_dict[self.m_ui.m_viewer].on_start_practise()
-                self.m_running_exercise = fn
+            self.handle_solfege_href(href, action, fn, anchor, lessoncollection,
+                                     lessonfile, config)
         elif protocol == 'http':
             webbrowser.open_new(href)
         elif protocol == 'mailto':
             os.system(self.get_string("config/mua") % href)
         else:
             print "unknown link type", protocol
+    def handle_solfege_href(self, href, action, fn, anchor, lessoncollection,
+                            lessonfile, config):
+        if action == 'all-lessonfiles':
+            self.m_ui.display_html(self.lessonfile_manager.m_htmldoc)
+            self.m_ui.m_history.add('solfege:all-lessonfiles')
+            return
+        if lessonfile:
+            filepath = os.path.join(self.get_string('lessoncollections/%s' %lessoncollection), lessonfile)
+            if not os.path.isfile(filepath):
+                self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
+                return
+        if (self.m_ui.m_viewer == 'docviewer'
+                   and self.m_running_exercise is not None
+                   and self.m_running_exercise != fn) or \
+                  (self.m_ui.m_viewer != 'docviewer'):
+            self.m_ui.box_dict[self.m_running_exercise].on_end_practise()
+            self.m_running_exercise = None
+        _old_viewer = self.m_ui.m_viewer
+        if fn not in self.m_teachers:
+            new_ex = True
+            n = utils.exercise_name_to_module_name(fn)
+            exec("import %s" % n)
+            if issubclass(locals()[n].Teacher, abstract.LessonbasedTeacher):
+                self.m_teachers[fn] = locals()[n].Teacher(fn, self, lessoncollection, lessonfile, config)
+            else:
+                self.m_teachers[fn] = locals()[n].Teacher(fn, self, config)
+            # if we don't have a teacher, then the Gui has not been
+            # initialized either
+            self.m_ui.initialise_exercise(self.m_teachers[fn])
+            self.m_teachers[fn].g_view = self.m_ui.box_dict[fn]
+        else:
+            new_ex = False
+            self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
+        self.m_ui.activate_exercise(href)
+        if not (_old_viewer == 'docviewer'
+                and self.m_running_exercise is not None
+                and self.m_running_exercise == fn):
+            self.m_ui.box_dict[self.m_ui.m_viewer].on_start_practise()
+        self.m_running_exercise = fn
     def quit_program(self):
         cfg.sync()
         for teacher in self.m_teachers.itervalues():
