@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,11 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'chord',
-    'menu_path': '%s/%s' % (_("_Chords"), _("_Chords")),
-    'icon': 'graphics/chord24.png',
-    'toolbar': 0,
-    #'accel_key': gtk.keysyms.F2,
-    #'accel_mods': 0,
+    'stock-icon': 'solfege-chord',
+    'menupath': '/Menubar/FileMenu/ChordsMenu',
+    'name': _('_Chords'),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
