@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@ import gobject
 
 __exercise_data__ = {
     'exercise_name': 'chord-voicing',
-    'menu_path': '%s/%s' % (_("_Chords"), _("_Chord voicing")),
     'stock-icon': 'solfege-chord-voicing',
-    'toolbar': 1,
+    'menupath': '/Menubar/FileMenu/ChordsMenu',
+    'name': _('_Chord voicing'),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
