@@ -15,16 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import os
-
 MAJOR_VERSION = 2
-MINOR_VERSION = 3
-PATCH_LEVEL = 2
+MINOR_VERSION = 4
+PATCH_LEVEL = 0
 VERSION_STRING = '%s.%s.%s' % (MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL)
-if "yes" == "yes":
-    WITH_GNOME = 1
-else:
-    WITH_GNOME = 0
-WITH_GTKHTML = "yes" == 'yes'
 HAVE_LINUX_AWE_VOICE_H = "yes" == "yes"
 ENABLE_TUNER = "no" == "yes"
