@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'dictation',
-    'menu_path': '%s/%s' % (_("_Misc exercises"), _("_Dictation")),
-    'icon': 'graphics/dictation24.png',
-    'toolbar': 6,
+    'stock-icon': 'solfege-dictation',
+    'menupath': '/Menubar/FileMenu/MiscMenu',
+    'name': _('_Dictation'),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
@@ -66,6 +66,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_question_title = gu.bLabel(self.practise_box, "", False, False)
 
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
+        self.set_size_request(500, -1)
         self.g_music_displayer.show()
         self.practise_box.pack_start(self.g_music_displayer)
         ###############
@@ -75,14 +76,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_go_back = gtk.Button(stock='gtk-go-back')
         self.g_go_back.connect('clicked', self.select_previous)
         self.g_go_back.show()
-        if configureoutput.WITH_GNOME:
-            self.g_go_back.get_children()[0].get_children()[0].get_children()[1].hide()
+        self.g_go_back.get_children()[0].get_children()[0].get_children()[1].hide()
         self.action_area.pack_start(self.g_go_back, False)
         self.g_go_forward = b = gtk.Button(stock='gtk-go-forward')
         self.g_go_forward.show()
         self.g_go_forward.connect('clicked', self.select_next)
-        if configureoutput.WITH_GNOME:
-            self.g_go_forward.get_children()[0].get_children()[0].get_children()[1].hide()
+        self.g_go_forward.get_children()[0].get_children()[0].get_children()[1].hide()
         self.action_area.pack_start(self.g_go_forward, False)
         self.g_play = gu.bButton(self.action_area, _("_Play the whole music"),
                                  self.play)
@@ -209,14 +208,13 @@ class Gui(abstract.LessonbasedGui):
     def display_start_of_music(self):
         fontsize = self.get_int('config/feta_font_size=20')
         if self.m_t.m_P.get_clue_music():
-                self.g_music_displayer.display(self.m_t.m_P.get_clue_music(),
-                                               fontsize)
+            self.g_music_displayer.display(self.m_t.m_P.get_clue_music(), fontsize)
         elif self.m_t.m_P.get_clue_end():
-                self.g_music_displayer.display_range(self.m_t.m_P.get_music(),
-                               fontsize, Rat(0, 1), self.m_t.m_P.get_clue_end())
+            self.g_music_displayer.display_range(self.m_t.m_P.get_music(),
+                        fontsize, Rat(0, 1), self.m_t.m_P.get_clue_end())
         else:
-                self.g_music_displayer.display(self.m_t.m_P.get_music(),
-                                               fontsize, mpd.FIRST)
+            self.g_music_displayer.display(self.m_t.m_P.get_music(), 
+                        fontsize, mpd.FIRST)
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = const.QSTATUS_NEW
         if self.m_t.m_P:
@@ -252,10 +250,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def create_pixmap_button(self):
         im = gtk.Image()
-        im.set_from_file(os.path.join("graphics", "rhythm-c4.png"))
+        im.set_from_stock("solfege-rhythm-c4", gtk.ICON_SIZE_LARGE_TOOLBAR)
+        im.show()
         btn = gtk.Button()
         btn.add(im)
-        im.show()
         return btn
     def on_start_practise(self):
         self.g_play.grab_focus()
