@@ -17,6 +17,7 @@
 
 import gtk
 import gnome
+import gobject
 import soundcard
 import cfg
 
@@ -150,24 +151,23 @@ class nCombo(gtk.Combo, cfg.ConfigUtils):
     def entry_changed(self, entry):
         self.set_int(self.m_name, self.popdown_strings.index(entry.get_text()))
 
-class PercussionNameOptionMenu(gtk.OptionMenu, cfg.ConfigUtils):
+class PercussionNameComboBoxEntry(gtk.ComboBoxEntry, cfg.ConfigUtils):
     def __init__(self, exname, name, default):
-        gtk.OptionMenu.__init__(self)
+        liststore = gtk.ListStore(gobject.TYPE_STRING)
+        for pn in soundcard.percussion_names:
+            liststore.append((pn,))
+        gtk.ComboBoxEntry.__init__(self, liststore)
         cfg.ConfigUtils.__init__(self, exname)
         self.m_name = name
-        menu = gtk.Menu()
-        for pn in soundcard.percussion_names:
-            menu.add(gtk.MenuItem(pn))
-        self.set_menu(menu)
         i = self.get_int(name)
         if not i:
             i = soundcard.percussionname_to_int(default)
             self.set_int(name, i)
-        self.set_history(i-35)
+        self.child.set_text(soundcard.int_to_percussionname(i))
         self.connect("changed", self.entry_changed)
     def entry_changed(self, widget):
         #FIXME value 35 should be taken from soundcard module.
-        self.set_int(self.m_name, widget.get_history()+35)
+        self.set_int(self.m_name, widget.get_active()+35)
 
 
 class FlashBar(gtk.Frame):
@@ -175,7 +175,7 @@ class FlashBar(gtk.Frame):
         gtk.Frame.__init__(self)
         self.set_shadow_type(gtk.SHADOW_IN)
         #FIXME different gtk themes can make these values wrong
-        self.set_size_request(358, 40)
+        self.set_size_request(-1, 40)
         self.__stack = []
         import widgets
         self.__label = widgets.HarmonicProgressionLabel('')
@@ -187,7 +187,7 @@ class FlashBar(gtk.Frame):
         we old flashed message are removed.
         """
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
         self.__label.set_text(txt)
         def f(self=self):
             self.__timeout = None
@@ -195,11 +195,11 @@ class FlashBar(gtk.Frame):
                 self.__label.set_text(self.__stack[-1])
             else:
                 self.__label.set_text('')
-        self.__timeout = gtk.timeout_add(2000, f)
+        self.__timeout = gobject.timeout_add(2000, f)
     def push(self, txt):
         # stop any flashing before we push
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
             self.__timeout = None
         self.__stack.append(txt)
         self.__label.set_text(txt, '')
