@@ -22,7 +22,7 @@ __exercise_data__ = {
     'name': _("Harmonic _progression dictation"),
 }
 import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
+#exercise_setup.register_exercise(__exercise_data__)
 
 import gtk, gnome
 import abstract, idbyname, const, gu, statisticsviewer, widgets
