@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,8 +54,8 @@ def langs():
             retval.append(s)
     return retval
 
-def setup():
-    gettext.install('solfege', os.path.join(configureoutput.prefix, 'share/locale'), unicode=1)
+def setup(prefix):
+    gettext.install('solfege', os.path.join(prefix, 'share', 'locale'), unicode=1)
     __builtins__['_i'] = _i
 
 def setup_srcdir():
