@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'identify-bpm',
-    'menu_path': '%s/%s' % (_("_Rhythm"), _("_Bpm")),
     'stock-icon': 'solfege-identify-bpm',
-    'toolbar': 12,
+    'menupath': '/Menubar/FileMenu/RhythmMenu',
+    'name': _("_Bpm"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
