@@ -23,13 +23,10 @@ import __builtin__
 __builtin__.app_running = True
 __builtin__.__exdata__ = []
 
-import sys, os, time, random
-
-if sys.version_info < (2, 3):
-    print "********************************************************************"
-    print "Solfege need Python 2.3 or newer. The configure script told you so!"
-    print "********************************************************************"
-    sys.exit(-1)
+import sys
+import os
+import time
+import runtime
 
 import configureoutput
 
@@ -49,6 +46,13 @@ opt_parser.add_option('--no-sound', action='store_true', dest='no_sound',
     help='Do not play any sounds. Useful when porting.')
 opt_parser.add_option('--no-random', action='store_true', dest='no_random',
     help='For debugging only: Select questions from lesson files in sequential order.')
+opt_parser.add_option('--without-gtkhtml', action='store_true', 
+    dest='without_gtkhtml',
+    help='Run without gtkhtml2 even if it is installed')
+opt_parser.add_option('--without-gnome', action='store_true', 
+    dest='without_gnome',
+    help='Run without the gnome module even if it is installed')
+
 
 options, args = opt_parser.parse_args()
 
@@ -83,28 +87,12 @@ USA.
 
 # silent, GNOME, be silent!
 sys.argv.append('--disable-sound')
-
-import pygtk
-# this is needed for py2exe
-if sys.platform == 'win32':
-    os.environ['PATH'] += ";lib;bin;"
-else:
-    pygtk.require("2.0")
-
-if not configureoutput.WITH_GNOME:
-    sys.path.insert(0, "gnomeemu")
+runtime.init(options)
 
 import gtk
 
-if gtk.pygtk_version < (1, 99, 11):
-    print "-"*55
-    print " GNU Solfege requires pygtk version 1.99.11 or newer."
-    print " The version installed appears to be", gtk.pygtk_version, "."
-    print " Exiting program."
-    print "-"*55+"\n"
-    sys.exit(-1)
-
-gtk.rc_parse("solfege.gtkrc")
+if not runtime.has_gnome():
+    sys.path.insert(0, "gnomeemu")
 
 class SplashWin(gtk.Window):
     def __init__(self):
@@ -130,7 +118,7 @@ class SplashWin(gtk.Window):
         while gtk.events_pending():
             gtk.main_iteration(0)
 
-if options.no_splash:
+if not options.no_splash:
     splash_win = SplashWin()
     time.sleep(0.1)
     gtk.gdk.flush()
@@ -162,16 +150,21 @@ sys.stderr = tracebackwindow.TracebackWindow()
 import const
 import app
 from htmlwidget import HtmlWidget
-import utils, history
+import utils
+import history
 from configwindow import ConfigWindow
 import soundcard
-import mpd, mpd.musicdisplayer, gu, cfg
+import mpd
+import mpd.musicdisplayer
+import gu
+import cfg
 import stock
 
-
 import chord
-import chordvoicing, harmonicinterval, melodicinterval,\
-       singinterval
+import chordvoicing
+import harmonicinterval
+import melodicinterval
+import singinterval
 
 import exercise_setup
 exercise_setup.register_exercise({
@@ -183,9 +176,16 @@ exercise_setup.register_exercise({
     'action': 'start-exercise-scales',
 })
 
-import idbyname, dictation, twelvetone, \
-       idtone, compareintervals, singchord, rhythm, identifybpm, \
-       harmonicprogressiondictation, singanswer
+import idbyname
+import dictation
+import twelvetone
+import idtone
+import compareintervals
+import singchord
+import rhythm
+import identifybpm
+import harmonicprogressiondictation
+import singanswer
 #import example
 
 exercise_setup.register_exercise({
@@ -297,7 +297,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
           ('HelpMenu', None, _('_Help')),
-          ('HelpHelp', 'gtk-help', 'Help on current exercise', 'F1', None,
+          ('HelpHelp', 'gtk-help', _('_Help on current exercise'), 'F1', None,
             lambda o: self.m_app.please_help_me()),
           ('HelpWelcome', None, _('_Welcome'), None, None,
             lambda o: self.m_app.handle_href('welcome.html')),
@@ -315,11 +315,11 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             lambda o: self.m_app.handle_href('bug-reporting.html')),
           ('HelpAbout', 'gtk-about', None, None, None, self.show_about_window),
           ('AppQuit', 'gtk-quit', None, None, None, self.quit_program),
-          ('ViewZoomIn', 'gtk-zoom-in', _('Help viewer zoom in'), None, None,
+          ('ViewZoomIn', 'gtk-zoom-in', _('Help viewer zoom in'), '<ctrl>plus', None,
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in()),
-          ('ViewZoomOut', 'gtk-zoom-out', _('Help viewer zoom out'), None, None,
+          ('ViewZoomOut', 'gtk-zoom-out', _('Help viewer zoom out'), '<ctrl>minus', None,
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_out()),
-          ('ViewZoom100', 'gtk-zoom-100', _('Help viewer zoom reset'), None, None,
+          ('ViewZoom100', 'gtk-zoom-100', _('Help viewer zoom reset'), '<ctrl>equal', None,
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset()),
           ('BrowserGoBack', 'gtk-go-back', None, None, None, self.history_back),
           ('BrowserGoForward', 'gtk-go-forward', None, None, None, self.history_forward),
@@ -343,7 +343,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         a.connect('activate', lambda w: self.set_bool('gui/toolbar_visible', w.get_active()))
         self.g_action_group.add_action(a)
 
-        if configureoutput.WITH_GTKHTML:
+        if runtime.has_gtkhtml2():
             self.g_ui_manager.add_ui_from_string("""\
 <menubar name='Menubar'>
  <menu action='ViewMenu'>
@@ -354,6 +354,15 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
 </menubar>""")
 
         self.add_accel_group(self.g_ui_manager.get_accel_group())
+        self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.KP_Equal,
+           gtk.gdk.CONTROL_MASK, 0,
+           lambda w, a, b, c: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset())
+        self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.KP_Subtract,
+           gtk.gdk.CONTROL_MASK, 0,
+           lambda w, a, b, c: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_out())
+        self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.KP_Add,
+           gtk.gdk.CONTROL_MASK, 0,
+           lambda w, a, b, c: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_in())
         for e in __exdata__:
             if 'menupath' in e:
                 a = gtk.Action(e['action'], e['name'], e['exercise_pretty_name'], e['stock-icon'])
@@ -406,7 +415,8 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if err_pos:
             msg = _("Error found in %s:\n") % err_pos + "\n" + msg
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
-                              gtk.BUTTONS_CLOSE, msg)
+                              gtk.BUTTONS_CLOSE, None)
+        m.set_markup(msg)
         m.run()
         m.destroy()
     def display_question_music_error_message(self, idx, lessonfile, exception, err_file=None):
@@ -502,6 +512,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.m_app.handle_href(self.m_history.get_current()[0])
         self.m_history.unlock()
     def initialise_exercise(self, teacher):
+        """
+        Create a Gui object for the exercise and add it to
+        the box_dict dict.
+        """
         assert teacher.m_exname not in self.box_dict
         n = utils.exercise_name_to_module_name(teacher.m_exname)
         self.box_dict[teacher.m_exname] = globals()[n].Gui(teacher, self)
@@ -509,7 +523,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def on_key_press_event(self, widget, event):
         if event.type == gtk.gdk.KEY_PRESS:
             for s in self.m_key_bindings:
-                if (event.state & (gtk.gdk.CONTROL_MASK|gtk.gdk.SHIFT_MASK), event.keyval) \
+                if (event.state & (gtk.gdk.CONTROL_MASK|gtk.gdk.SHIFT_MASK|gtk.gdk.MOD1_MASK), event.keyval) \
                          == utils.parse_key_string(self.get_string(s)):
                     self.m_key_bindings[s]()
                     return 1
