@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
 
 __exercise_data__ = {
     'exercise_name': 'melodic-interval',
-    'menu_path': '%s/%s' % (_("_Intervals"), _("_Melodic intervals")),
     'stock-icon': 'solfege-melodic-interval',
-    'toolbar': 3,
+    'menupath': '/Menubar/FileMenu/IntervalsMenu',
+    'name': _("_Melodic intervals"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
@@ -29,6 +29,7 @@ import gu, widgets, inputwidgets
 import abstract, const
 import statistics, statisticsviewer
 import soundcard, utils, mpd
+import intervaltest
 
 class Teacher(abstract.MelodicIntervalTeacher):
     exercise_data = __exercise_data__
@@ -67,6 +68,7 @@ class Teacher(abstract.MelodicIntervalTeacher):
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
         abstract.IntervalGui.__init__(self, teacher, window)
+        self.g_test_stat_dlg = None
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"), self.give_up)
         self.g_give_up.set_sensitive(False)
         ##############
@@ -95,16 +97,12 @@ class Gui(abstract.IntervalGui):
         hbox.set_spacing(gnome.ui.PAD_SMALL)
         gu.bLabel(hbox, _("Input interface:"), False)
 
-        optionmenu = gtk.OptionMenu()
-        menu = gtk.Menu()
+        combo = gtk.combo_box_new_text()
         for i in range(len(inputwidgets.inputwidget_names)):
-            item = gtk.MenuItem(inputwidgets.inputwidget_names[i])
-            menu.add(item)
-            item.connect('activate',
-                         lambda widget, i=i: self.use_inputwidget(i))
-        optionmenu.set_menu(menu)
-        optionmenu.set_history(self.get_int('inputwidget'))
-        hbox.pack_start(optionmenu, False)
+            combo.append_text(inputwidgets.inputwidget_names[i])
+        combo.set_active(self.get_int('inputwidget'))
+        combo.connect('changed', lambda w: self.use_inputwidget(w.get_active()))
+        hbox.pack_start(combo, False)
 
         self.g_disable_unused_buttons = gu.nCheckButton(self.m_exname,
                     'disable_unused_intervals', _("_Disable unused buttons"))
@@ -115,7 +113,26 @@ class Gui(abstract.IntervalGui):
         ##############
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
                                     _("Melodic interval"))
+        ########
+        # Test #
+        ########
+        self.g_action_group = gtk.ActionGroup('MelodicIntervalActions')
+        self.g_action_group.add_actions([
+            ('ExerciseMenu', None, _('_Exercise')),
+            ('TestEx', None, _('_Run test'), None, None, self.run_test),
+            ('MelodicIntervalTestStatistics', None, _('_Test statistics'), None, None,
+             self.show_test_statistics),
+            ])
+        self.g_win.g_ui_manager.insert_action_group(self.g_action_group, 0)
         self.select_inputwidget()
+    def run_test(self, *v):
+        tw = intervaltest.MelodicIntervalTestDialog()
+        tw.set_modal(True)
+        tw.show_all()
+        gtk.main()
+        self.g_test_stat_dlg = intervaltest.TestStatisticsDialog(self, _("Melodic interval test results"), tw.m_test.get_test_results_dict(), False)
+        self.g_test_stat_dlg.show_all()
+        tw.destroy()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
             s = utils.int_to_intervalname(self.m_t.m_question[0],
@@ -206,10 +223,20 @@ class Gui(abstract.IntervalGui):
             self.g_flashbar.flash(_("You have to solve this question first."))
     def on_start_practise(self):
         self.m_t.m_statistics.reset_session()
+        self.g_action_group.set_sensitive(True)
         self.g_new_interval.grab_focus()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New interval' to begin.")))
+        self.g_merge_id = self.g_win.g_ui_manager.add_ui_from_string("""
+<menubar name='Menubar'>
+  <menu action='ExerciseMenu'>
+    <menuitem action='TestEx'/>
+    <menuitem action='MelodicIntervalTestStatistics'/>
+  </menu>
+</menubar>""")
     def on_end_practise(self):
+        if self.g_merge_id:
+            self.g_win.g_ui_manager.remove_ui(self.g_merge_id)
         self.m_t.end_practise()
         self.g_new_interval.set_sensitive(True)
         self.g_repeat.set_sensitive(False)
