@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2004  Tom Cato Amundsen
+# Copyright (C) 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,10 @@
 
 __exercise_data__ = {
     'exercise_name': 'singanswer',
-    'menu_path': '%s/%s' % (_("_Chords"), _("_Sing answer")),
+    'stock-icon': 'solfege-sing-answer',
+    'menupath': '/Menubar/FileMenu/ChordsMenu',
+    'name': _("_Sing answer"),
+    'notoolbar': True,
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
