@@ -24,7 +24,7 @@ except:
     import i18n
     i18n.setup_srcdir()
 
-
+import os
 import gtk
 import re, math
 import mpd
@@ -168,9 +168,7 @@ def parse_url(s):
         V = m.group('config').split(";")
         for e in V:
             n, v = e.split("=")
-            n = n.strip(n)
-            v = v.strip(v)
-            D[n.strip()] = v
+            D[n.strip()] = v.strip()
     for k in D:
         D[k] = un_escape_url_string(D[k])
     return m.group('protocol'), m.group('action'), m.group('fn'), \
@@ -179,7 +177,7 @@ def parse_url(s):
 def get_modifier(s):
     m = (('<ctrl>', gtk.gdk.CONTROL_MASK),
          ('<shift>', gtk.gdk.SHIFT_MASK),
-         ('<alt>', 8))#gtk.gdk.MOD1_MASK))
+         ('<alt>', gtk.gdk.MOD1_MASK))
     for mod, mask in m:
         if s.startswith(mod):
             return mask, s[len(mod):]
@@ -253,3 +251,4 @@ if __name__ == '__main__':
     print parse_url("main.html")
     print parse_url("exercise:/main.html#23")
     print parse_url("solfege:practise/id-by-name/solfege/fifth-small-pure-0.99")
+    print parse_url("solfege:/harmonic-interval?intervals=[1, 2, 3]")
